%CHECKDISSIM Check and normalize dissimilarity matrix
%
%		D = CHECKDISSIM(D)
%
% INPUT
%   D      Dissimilarity matrix, dataset or double
%
% OUTPUT
%   D      Normalized dissimilarity matrix.
%
% DESCRIPTION
% It is checked whether the input matrix is a propor dissimilarity matrix
% (square, zero diagonal, non-negative). It is made symmetric by averaging
% with its transpose, a small random value is added to make all entries
% different and it is normalized (maximum is put on one). 

% Copyright: R.P.W. Duin, r.p.w.duin@37steps.com

function d = checkdissim(d)

  % avoid PRTools dataset overhead (create double)
  d = +d;          
  m = size(d,1);
  
  % check on proper dissimilarity matrix
  isdissim(d);     

  % make sure all objects are different
  seed = randreset;  % get random seed settings
  randreset(1);      % set seed for reproducability
  d = d + rand(m,m)*max(d(:))*1e-10;
  randreset(seed);   % restore random seed settings

  % make diagonal zero
  t = eye(size(d,1)) == 1;	
  d(t) = zeros(m,1);

  % create symmetric matrix
  d = (d+d')/2; 

  % normalize
  d = d/max(d(:));

return