%CLUSTINDS Find object indices in cluster
%
%   [IND,FIRST,LAST] = CLUSTINDS(LAB)
%
% INPUT
%   LAB      Column vector with N cluster labels. In total C clusters
%
% OUTPUT
%   IND      Column vector with N indices ranging from 1 to N.
%   FIRST    Column vector with C start points in IND of a cluster.
%   LAST     Column vector with C end points in IND of a cluster
%            LAST(I) = FIRST(I+1)-1, LAST(END) = N.
%
% DESCRIPTION
% In case cluster labels in LAB are not sorted this routine is useful to
% group them. Cluster K can be found by LAB(IND(FIRST(K):LAST(K))).

% SEE ALSO (<a href="http://37steps.com/clustertools">ClusterTools Guide</a>)
% CLUSTE, CLUSTF, CLUSTH, CLUSTK, CLUSTKH, CLUSTM, EXEMPLAR, MEANSHIFT, 
% MODECLUST, MODECLUSTF, DCLUSTE, DCLUSTM, DCLUSTH, DCLUSTK, CLUSTNUM,
% CLUSTSIZES

% Copyright: R.P.W. Duin, r.p.w.duin@37steps.com

function [R,F,L] = clustinds(lab)

[~,~,J] = unique(lab);
[S,R] = sort(J);
[~,F] = unique(S);
L = [F(2:end)-1; numel(S)];
