%CLUSTSIZES Cluster sizes and prototypes in multilevel clustering
%
%    [SIZES,PROTOS] = CLUSTSIZES(LABELS)
%    [SIZES,PROTOS] = LABELS*CLUSTSIZES
%     CLUSTSIZES(LABELS)
%     LABELS*CLUSTSIZES
%
%   LABELS [M,L] array of indices for L levels of clustering
%
%   SIZES   Cell array of L cells. Each cell contains a vector of C 
%           elements (C is the numbers of clusters on the particular level)
%           with the numbers of objects in the corresponding cluster.
%   PROTOS  Cell array of L cells. Each cell contains a vector of C 
%           elements with the prototype indices of the clusters.
%
% DESCRIPTION
% The sizes and the prototype indices of a multi-clustering result LABELS
% are returned in the cells of SIZES and PROTOS.
%
% In case of no output variables the sizes of the 10 largest clusters are.
% for every labeling, listed on the screen, followed by the sum of the
% unreported sizes.
%
% SEE ALSO (<a href="http://37steps.com/clustertools">ClusterTools Guide</a>)
% MAPPINGS, CLUSTE, CLUSTF, CLUSTH, CLUSTK, CLUSTKH, CLUSTM, EXEMPLAR, 
% MEANSHIFT, MODECLUST, MODECLUSTF, DCLUSTE, DCLUSTM, DCLUSTH, DCLUSTK, 
% CLUSTNUM

% Copyright: R.P.W. Duin, r.p.w.duin@37steps.com

function [out1,out2,out3] = clustsizes(varargin)

labels = setdefaults(varargin);
if mapping_task(varargin,'definition')
  
  out1 = prmapping(mfilename,'fixed');
  out1 = setname(out1,'ClusterSizes');
  
else
  
  [m,k] = size(labels);
  L = cell(1,k);
  N = cell(1,k);
  S = cell(1,k);
  for j=1:k
    [LL,I,J] = unique(labels(:,j));
    NN = histc(J,1:numel(I));
    [N{j},R] = sort(NN,'descend');
    L{j} = LL(R);
    S{j} = J;
  end

  if nargout == 0
    for j=1:numel(N)
      k = numel(N{j});
      fprintf('%6i : ',k);
      for i=1:min(k,10)
        fprintf(' %6i',N{j}(i))
      end
      if k > 10
        fprintf(' (%6i)',sum(N{j}(11:k)));
      end
      fprintf('\n')
    end
  else
    if k == 1
      out1 = N{1};
      out2 = L{1};
      out3 = S{1};
    else
      out1 = N;
      out2 = L;
      out3 = S;
    end
      
  end

end