%COLASS Assign a column vector to varying columns of an array
%
%   B = COLASS(A,C,X)
%
% INPUT
%   A    2D Array
%   C    Vector of column indices
%   X    Vector of column values to be assigned
%
% OUTPUT
%   B    2D output array
%
% DESCRIPTION
% B = A;
% B(i,C(i)) = X(i), i=1:size(A,1)
% The rows for which C(i) == 0 are skipped.

function out = colass(a,J,x)

[m,k] = size(a);
if numel(J) ~= m
  error('Vector with column indices has wrong size')
end
if numel(x) ~= m
  error('Vector with column values wrong size')
end

out = a;
L = find(J > 0);
out(sub2ind([m,k],L,J(L))) = x(L);