%DCLUSTE Examplar clustering, wrapper around EXEMPLAR
% 
% 	LAB = DCLUSTE(D,K)
%   LAB = D*DCLUSTE(K)
% 
% INPUT
%  D     Square dissimilarity matrix, size M*M, dataset or doubles
%  K     Scalar or a vector of length N with desired numbers of clusters.
%        Default is a set of N clusterings with numbers that naturally
%        arise from the data.
%  NEST  Logical, if TRUE a nested result is returned in case of
%        multi-level clustering. Default is TRUE unless K is given, as
%        nesting conflicts with demanding a number of clusters.
%
% OUTPUT
%  LAB   M*N array with the results of the multi-level clusterings for the
%        M objects. The columns refer to the N clusterings. They yield for
%        the objects the prototype indices of the clusters they belong to.
%
% DESCRIPTION
% This routine performs a clustering based on message passing between data
% points, see [1]. It is a wrapper around EXEMPLAR and uses its default
% parameter settings. EXEMPLAR does not return a predefined number of
% clusters. Therefore, if K is defined clustering is redefined by RECLUSTK,
% possibly at the cost of performance.
% 
% REFERENCES
% [1] B.J. Frey and D. Dueck, Clustering by passing messages between
%     data points, Science, vol. 315, pp. 972-976, 2007
%
% SEE ALSO (<a href="http://37steps.com/clustertools">ClusterTools Guide</a>)
% DATASETS, MAPPINGS, EXEMPLAR, DCLUSTM, DCLUSTH, DCLUSTK, CLUSTEVAL,
% CLUSTCERR, CLUSTC, RECLUSTK

% Copyright: R.P.W. Duin, r.p.w.duin@37steps.com


function labels = dcluste(varargin)

argin = shiftargin(varargin,'vector',1);
argin = shiftargin(argin,'logical',2);
[d,k] = setdefaults(argin,[],[]);
if mapping_task(argin,'definition')
  labels = prmapping(mfilename,'fixed',{k});
  labels = setname(labels,'Exemplar');
else
	labels = exemplar(d);
  k = k(k<size(d,1)/5);
  if ~isempty(k)
    labels = reclustk(labels,k,labels(:,3));
  end
  labels = labsort(labels,'upred');
end

return