%DCLUSTR Dissimilarity based random clustering
% 
% 	LAB = DCLUSTR(D,K)
% 	LAB = D*DCLUSTR(K)
%
% INPUT
%  D     Square dissimilarity matrix, size M*M
%  K     Scalar or a vector of length N with desired numbers of clusters.
%        Default is a set of N clusterings with numbers that naturally
%        arise from the data.
%
% OUTPUT
%  LAB   M*N array with the results of the multi-level clusterings for the
%        M objects. The columns refer to the N clusterings. They yield for
%        the objects the prototype indices of the clusters they belong to.
%
% DESCRIPTION
% The dataset A with M rows (objects) is clustered by selecting a random
% set of K prototypes out of A. All other objects are assigned to the
% nearest prototype. In case K is a set, larger sets of prototypes will
% contain the smaller ones.
%
% Clusterings can be evaluated by CLUSTEVAL, CLUSTCERR or CLUSTC on the
% basis of (some) true labels.
%
% SEE ALSO (<a href="http://37steps.com/clustertools">ClusterTools Guide</a>)
% DATASETS, MAPPINGS, KMEANS, PRKMEANS, CLUSTK, DCLUSTM, DCLUSTH, DCLUSTE,
% DCLUSTF, CLUSTEVAL, CLUSTCERR, CLUSTC

% Copyright: R.P.W. Duin, r.p.w.duin@37steps.com

function labels = dclustr(varargin)

argin = setdefaults(varargin,[],[]);
if mapping_task(argin,'definition')
  labels = prmapping(mfilename,'fixed');
else
  [d,k] = deal(argin{:});
  m = size(d,1);
  n = numel(k);
  if isempty(k)
    % generate set of k-values using a geometric series
    k = intgeos(2,1.21,m/5);  % neighborhood sizes in kNN modeseeking
  end
  labels = zeros(m,n);
  P = randperm(m,max(k));
  for i=1:n
    [~,r] = min(d(:,P(1:k(i))),[],2);
    labels(:,i) = P(r);
  end
end
return
