%DRANKM Rank dissimilarity matrix 
%
%   R = DRANKM(D)
%
% INPUT
%   D   Square dissimilarity matrix (dataset or double) having a zero
%       diagonal.
%
% OUTPUT
%   R   Dissimilarity matrix with dissimilarities replaced by their rank.
%
% DESCRIPTION
% All off-diagonal entries of the dissimilarity matrix D are replaced by
% their rank in the set of all dissimilarities. The diagonal is kept on
% zero. Finally R scaled such that the maximum dissimilarity is one.

% Copyright: R.P.W. Duin, r.p.w.duin@37steps.com


function r = drankm(d)

if nargin == 0 || isempty(d)
  
  r = prmapping(mfilename,'fixed');
  
else
  
  isdissim(d);
  m = size(d,1);
  d = d./max(max(+d)) + 1e-10*rand(m,m);
  d = d - diag(diag(+d));
  [~,r] = sort(+d(:));
  r(r) = [zeros(1,m) (1:m*(m-1))]/(m*(m-1));
  r = reshape(r,m,m);
  if isdataset(d)
    r = setdata(d,r);
  end
  
end