%EADIST Create evidence accumulation dissimilarity matrix
%
%   D = EADIST(LABELS)
%   D = LABELS*EADIST
%
% INPUT
%  LABELS  Multilevel labeling, size [M,K], for M objects.
%
% OUTPUT
%  D       MxM distance matrix
%
% DESCRIPTION
% This routine constructs from K sets of clusterlabels (doubles) of M
% objects stored in the MxK array LABELS an MxM dissimilarity matrix D.
%
% The preferred clustering of D is the single linkage hierarchical
% clustering, see DCLUSTH.
%
% REFERENCE
% A.L.N. Fred, A.K. Jain. Combining multiple clusterings using evidence
% accumulation, PAMI, 27.6 (2005): 835-850.
%
% SEE ALSO (<a href="http://37steps.com/clustertools">ClusterTools Guide</a>)
% DATASETS, MAPPINGS, DCLUSTH

function d = eadist(labs)

  if nargin < 1 || isempty(labs)
    d = prmapping(mfilename,'fixed');
  else
    d = labs*proxm(labs,'ndiff');
  end