%GENDATCLUST1 Generate data for 10-cluster analysis evaluation
%
%   A = GENDATCLUST1(N)
%
% Generate N objects in a 2D 10-class problem

function a = gendatclust1(n)

if nargin < 1 || isempty(n)
  n = 1000;
end
if isscalar(n)
  n = genclass(n,0.1*ones(1,10));
end
a = +gendatgauss(n(1),[0 0]);
a = [a; +gendatgauss(n(2),[5 0],diag([0.1 1]))];
a = [a; +gendatgauss(n(3),[0 5],diag([1 0.2]))];
a = [a; +gendatgauss(n(4),[5 5],[1 0.9; 0.9 1])];
a = [a; 2*rand(n(5),2)+repmat([7 11],n(5),1)];
a = [a; rand(n(6),2)*diag([4 8])+repmat([-2 8],n(6),1)];
a = [a; +selclass(genriver([n(7) n(7)],2,1),1)+repmat([9 1],n(7),1)];
a = [a; +selclass(genriver([n(8) n(8)],2,1),1)+repmat([9 3],n(8),1)];
a = [a; circle2d(n(9),0.1,'n')*3+repmat([8,12],n(9),1)];
a = [a; circle2d(n(10),1)*diag([4,4])+repmat([18 12],n(10),1)];
a = prdataset(a,genlab(n,[1:10]'));
a = setname(a,'Cluster example');


%GENRIVER Generate 2D 2-class River data
%
%		A = GENRIVER(N,L,S)
%
% INPUT
%   N    Number of objects in each of the classes (default: [50 50])
%   L    Length of the river, default: L = 1 (i.e. 2 bends)
%   S    Width of uniform class distribution on the river borders,
%        default: S = 1;
%
% OUTPUT
%   A    Generated dataset
%
% Generate a separable 'bending river'-like 2D dataset of two classes.
% Class priors are equal.
%
% EXAMPLE
%  repset = genriver([10 10],4);
%  trainset = genriver([],4);
%  w = proxm(repset,'d');
%  v = w*fisherc(trainset*w);
%  figure; scatterd(trainset); plotc(v)
%
% SEE ALSO
% DATASETS, PRDATASETS

% Copyright: A. Harol, R.P.W. Duin, r.p.w.duin@prtools.org
% Faculty EWI, Delft University of Technology
% P.O. Box 5031, 2600 GA Delft, The Netherlands

function a = genriver(N,len,s,d)

	prtrace(mfilename);
	
	if nargin < 4, d = 0; end
	if nargin < 3, s = 1; end
	if nargin < 2 | isempty(len), len = 1; end
	if nargin < 1 | isempty(N), N = [50 50]; end

	p = [0.5 0.5];
	N = genclass(N,p);	
	x1=len*2*pi*rand(1,N(1));
	x2=sin(x1)+(s*rand(size(x1)))+d;
	d1 = prdataset([x1',x2'],ones(size(x1')));
	x3=len*2*pi*rand(1,N(2));
	x4 = sin(x3)+(-s+s*rand(size(x3)))-d;
	d2 = prdataset([x3',x4'],2*ones(size(x3')));
	a = setprior([d1;d2],p);
	
return

