% GENDSET Generate data from a modeseeking based Parzen density etimate 
%
%    B = GENDSET(A,N)
%
% The multidimensional dataset A is first clustered in sqrt(N) clusters.
% Next for each cluster a Parzen density estimate is created and this is
% used to generate new data points.
%
% SEE ALSO (<a href="http://37steps.com/clustertools">ClusterTools Guide</a>)
% CLUSTM, GENDATP

% Copyright: R.P.W. Duin, r.p.w.duin@37steps.com


function b = gendset(a,n)

if nargin < 2 || isempty(n), n = 1000; end
k = round(min(sqrt(n),sqrt(size(a,1))));

dseta = isdataset(a);
if dseta
  laba = getnlab(a);
  lablist = getlablist(a);
  fsize = getfeatsize(a);
end
labc = clustm(a,k);
labu = unique(labc);
S = clustsizes(labc)';
P = normm(S);
M = genclass(n,P);

b = zeros(n,size(a,2));
labb = zeros(n,1);
a = prdataset(a,labc);
m = 0;
t = sprintf('Generating %i points: ',n);
prwaitbar(n,t);
for i=1:getsize(a,3)
  prwaitbar(n,m,[t num2str(m)]);
  ai = +selclass(a,i);
  bi = gendatp(ai,M(i));
  b(m+1:m+M(i),:) = bi;
  labb(m+1:m+M(i)) = repmat(laba(labu(i)),M(i),1);
  m = m+M(i);
end
prwaitbar(0)

if dseta
  b = prdataset(b,lablist(labb,:));
  b = setfeatsize(b,fsize);
end
  

  
