%ISDISSIM Test on proper dissimilarity matrix
%
%   OK = ISDISSIM(D)
%   ISDISSIM(D)
%
% INPUT
%   D     Dissimilarity matrix, dataset or double
%
% OUTPUT
%   OK    1 if the matrix D is proper and 0, otherwise.
%
% DESCRIPTION
% True if D is a proper dissimilarity matrix dataset: square, zero diagonal
% and positive dissimilarities. If called without an output argument 
% ISDISSIM generates an error if D is not proper.

% Copyright: R.P.W. Duin, r.p.w.duin@37steps.com

function ok = isdissim(d)
d = +d;
[m,n] = size(d);
ok = true;
if m ~= n
	if nargout == 0
		error('Square input array expected')
	else 
		ok = false;
	end
end
if (any(diag(d)) > realmin)
	if nargout == 0
		error('Distance matrix should have zeros on the diagonal')
	else 
		ok = false;
	end
end
if any(d(:) < 0)
	if nargout == 0
		error('Negative distance are not allowed')
	else 
		ok = false;
	end
end