%LABCOMP Compare two sets of labelings
%
%   [E1,E2] = LABCOMP(LAB1,LAB2,FAST)
%
% INPUT
%    LAB1   Vector with M numeric labels
%    LAB2   Vector with M numeric labels of the same objects
%    FAST   Logic, if TRUE (default) a random subset of 10000 of objects is
%           used to speed up the computation.
%
% OUTPUT
%    E1     Frequency that two objects with the same LAB1 have different 
%           labels LAB2
%    E2     Frequency that two objects with different LAB1 have the same 
%           labels LAB2

% Copyright: R.P.W. Duin, r.p.w.duin@37steps.com

function [e1,e2] = labcomp(lab1,lab2,fast)

if nargin < 3 || isempty(fast), fast = true; end

n1 = 0; n2 = 0;
e1 = 0; e2 = 0;
n  = numel(lab1);

% Use a random subset of 10000 objects for faster computations 
rstat = randreset;
if fast && n > 10000
  randreset;
  L = randperm(n);
  n = 10000;
  lab1 = lab1(L(1:n));
  lab2 = lab2(L(1:n));
end

% due to some Matlab magic the following loop is faster if the labels
% are systematically organised, so let us sort them
[lab1,R] = sort(lab1);
lab2 = lab2(R);

for j=1:n
  % find other objects with the same label
	JT = (lab1 == lab1(j)); 
	m = sum(JT);            % their number
  
  % find how often this does not hold for the k label estimates
	e1 = e1 + sum(lab2(JT) ~= repmat(lab2(j),m,1));
  % get counter correct
	n1 = n1 + m - 1; % correction for comparing point j with point j
	
  % repeat the same for all objects with a different label than the present
	JT = ~JT;
	m = sum(JT);   % their number
  % find how often this does not hold for the label estimate
	e2 = e2 + sum(lab2(JT) == repmat(lab2(j),m,1));
  % counter
	n2 = n2 + m;
end
%disp([e1,e2,n1,n2])
e1 = e1/n1;
e2 = e2/n2;
randreset(rstat);