%LABNMI Normalized mutual information of two labelings
%
%   NMI = LABNMI(LABC,LABT)
%
% INPUT
%    LABC   Array with MxK numeric labels
%    LABT   Vector with M numeric labels of the same objects
%
% OUTPUT
%    NMI    Vector with K normalized mutual information indices
%
% DESCRIPTION
% The value of NMI is 1 for fully consistent labelings and 0 for fully
% inconsistent labelings. This is independent of the actual label values.

% Copyright: R.P.W. Duin, r.p.w.duin@37steps.com

function nmi = labnmi(laba,labb)

if nargin < 2, labb = laba; end
m  = size(laba,1);
if size(labb,1) ~= m
  error('Clusterings should have the same number of objects')
end

nmi = zeros(1,size(laba,2));
n = numel(nmi);
t = sprintf('Evaluation %i labelings: ',n);
prwaitbar(n,t);
for i = 1:size(laba,2)
  lab1 = laba(:,i);
  prwaitbar(n,i,[t num2str(i)]);
  C = confmat(lab1,labb)/m;
  C1 = sum(C,2);
  C2 = sum(C,1);
  D = sum(C,2)*sum(C,1);
  L = find(C > 0);
  J = C(L).*log(C(L)./D(L));
  SJ = sum(J(:));
  MN = min(sum(-C1.*log(C1)),sum(-C2.*log(C2)));
  if SJ == MN            % take care of SJ =MN = 0
    nmi(1,i) = 1;
  else
    nmi(1,i) = sum(J(:))/MN;
  end
end
prwaitbar(0);