%MODECLUSTE Extend modeseek clustering to obtain large clusters
%
%   LABOUT = MODECLUSTE(A,LABIN)
% 
% INPUT
%   A       Dataset of M objects.
%   LABIN   Mulilevel clustering of A
%
% OUTPUT
%   LABOUT  Extended multilevel clustering of A with low-resolution levels 
%
% DESCRIPTION
% This routine is especially useful in combination with MODECLUSTF to
% obtain more low-resolution clustering levels. However, it may also
% improve other low-resolution results, e.g. as obtained by MODECLUST.
%
% The routine is based on a modeseeking clustering of the input cluster
% prototypes, preferably 1000 to 5000. This results in a multilevel
% clustering having one to about one hundred prototype clusters. They are
% extended with their cluster members and concatenated with the levels in
% LABIN.
%
% SEE ALSO (<a href="http://37steps.com/clustertools">ClusterTools Guide</a>)
% MODECLUST, MODECLUSTF, RECLUSTN

% Copyright: R.P.W. Duin, r.p.w.duin@37steps.com


function labout = modecluste(a,labin)

labin = reclustn(labin);  % make multi-level clustering nested
L = clustnum(labin);       % find number of clusters per level
n = find(L < 5000,1);    % find largest level with less than 5000 clusters
if isempty(n)            % if not available ...
  n = numel(L);          % use smallest one
end
[S,~,IS] = unique(labin(:,n)); % find prototypes and indices
labs = modeclust(a(S,:));% cluster cluster prototypes
labsh = reclustn(labs);   % nest them

% now the clusters of the prototypes are extended with their members
labext = zeros(size(labin,1),size(labsh,2)); % mske space
for i=1:size(labsh,2)    % run over prototype cluster levels
  labext(:,i) = S(labsh(IS(labin(:,n)),i)); % etend them
end
labout = nestlab([labin labext]); % combine them with input and nest