%RECLUSTE Extend the set of clusterings with lower level clusterings.
%
%   LABOUT = RECLUSTN(A,LABIN)
%
% INPUT
%   A       Dataset with M objects
%   LABIN   M*N index array with a multi-level clustering of A.
%
% OUTPUT
%  LABOUT   MxK index array with K >= N of an extended multi-level
%           clustering of A. 
%
% DESCRIPTION
% In case the numbers of clusters of all levels of the clusterings stored
% in LABIN (they might be found by CLUSTNUM) is too large and clusterings
% with less clusters are to be found RECLUSTN extends LABIN with
% low-resolution clusterings. This is done by clustering just the 
% prototypes of a high-resolution clustering found in in LABIN, using
% MODECLUST.
%
% SEE ALSO (<a href="http://37steps.com/clustertools">ClusterTools Guide</a>)
% MEANSHIFT, MODECLUST, MODECLUSTF, CLUSTM, DCLUSTM, LABSORT, RECLUSTK,
% RECLUSTH, CLUSTNUM

% Copyright: R.P.W. Duin, r.p.w.duin@37steps.com

function labout = clustext(a,labin)

labin = labsort(labin,'down');
% Find the largest one smaller that 10*the smallest
S = clustnum(labin);
n = find(S < 10*min(S),1);
if isempty(n) % otherwise take the smallest one
  n = numel(S);
end
% store the cluster prototypes in S
[U,~,IU] = unique(labin(:,n)); % IS will index them
labs = modeclust(a(U,:));      % modeseek cluster the selected prototypes
% apply the clusterings of the prototypes to all objects they represent
labext = zeros(size(labin,1),size(labs,2));
for i=1:size(labs,2)   
  labext(:,i) = U(labs(IU(labin(:,n)),i));
end
labout = labsort([labin labext],'downred'); % extend the multi-level clustering
labout = fliplr(labout);
