%SCATN 2D scatterplot for showing clusterresults
%
%  SCATN(LAB,DATA,TITLE)
%  LAB*SCATN
%
% INPUT
%  LAB    Vector of M indices pointing to the cluster prototypes of all
%         objects in DATA.
%  DATA   2D dataset or double array with M objects (rows). 
%  TITLE  Title to be plotted on top of the scatterplot.
%
% DESCRIPTION
% This routine produces a scatterplot of DATA and labels it according to
% the clustering given in LAB. In case DATA and TITLE are not given it uses
% the data of the previous scatterplot produced by SCATN.
%
% SEE ALSO (<a href="http://37steps.com/clustertools">ClusterTools Guide</a>)
% DATASETS, MAPPINGS, DCLUSTE, DCLUSTF, DCLUSTH, DCLUSTF, DCLUSTM, DCLUSTR,
% CLUSTE, CLUSTF CLUSTK, CLUSTM, CLUSTKH, MODECLUSTF, CLUSTEVAL, 
% CLUSTCERR, CLUSTC, CLUSTNUM, CLUSTHC, PLOTDG

% Copyright: R.P.W. Duin, r.p.w.duin@37steps.com

function h = scatn(varargin)

argin = shiftargin(varargin,'prdataset',1);
argin = setdefaults(argin,[],[],[]);
if mapping_task(argin,'definition')
  % definition of the mapping in case of A*SCATN([],PARS)
  h = define_mapping(argin,'fixed');
else
  [lab,a,s] = deal(argin{:});
  if isempty(a)
    error('No data supplied')
  end
  if isempty(s) && isdataset(a)
    s = getname(a);
  end
  
  if size(lab,1) ~= size(a,1);
    error('Number of labels should be equal to number of objects');
  end

  if size(a,2) > 2
    prwarning(3,'Just first two feature of dataset are plotted')
  end
  
  if size(lab,2) > 1
    prwarning(3,'Just first clustering of the mulitlevel clustering is shown')
  end

  scattern(prdataset(+a(:,1:2),lab(:,1)));
  marksize(17-ceil(log10(size(a,1))*3));
  title(s);
  
  if nargout > 0, h = gcf; end
  
end